Rectangle

Struct Rectangle 

pub struct Rectangle<S> { /* private fields */ }
Rectangle primitive.

Have a cached set of corner points to speed up computation.

Implementations

Source

impl<S> Rectangle<S>
where S: BaseFloat,

pub fn new(dim_x: S, dim_y: S) -> Rectangle<S>

Create a new rectangle primitive from component dimensions

pub fn new_impl(dim: Vector2<S>) -> Rectangle<S>

Create a new rectangle primitive from a vector of component dimensions

pub fn dim(&self) -> &Vector2<S>

Get the dimensions of the Rectangle

pub fn half_dim(&self) -> &Vector2<S>

Get the half dimensions of the Rectangle