Material

Struct Material 

pub struct Material { /* private fields */ }
Physics material

Used to describe physical properties of physical entities, such as density and restitution.

The default material has density 1, such that only the volume affects its mass, and restitution 1, such that all energy is preserved in collisions.

Implementations

Source

impl Material

pub const ROCK: Material

Rock

pub const WOOD: Material

Wood

pub const METAL: Material

Metal

pub const BOUNCY_BALL: Material

Bouncy Ball

pub const SUPER_BALL: Material

Super Ball

pub const PILLOW: Material

Pillow

pub const STATIC: Material

Static

pub fn new(density: f32, restitution: f32) -> Self

Create new material

pub fn density<S>(&self) -> S
where S: BaseFloat,

Get density

pub fn restitution<S>(&self) -> S
where S: BaseFloat,

Get restitution