pub struct Material { /* private fields */ }Expand description
Physics material
Used to describe physical properties of physical entities, such as density and restitution.
The default material has density 1, such that only the volume affects its mass, and restitution 1, such that all energy is preserved in collisions.
Implementations
Sourceimpl Material
impl Material
Sourcepub const BOUNCY_BALL: Material
pub const BOUNCY_BALL: Material
Bouncy Ball
Sourcepub const SUPER_BALL: Material
pub const SUPER_BALL: Material
Super Ball
Sourcepub fn restitution<S>(&self) -> Swhere
S: BaseFloat,
pub fn restitution<S>(&self) -> Swhere
S: BaseFloat,
Get restitution